package org.apache.bcel.generic;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.DataInput;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.apache.bcel.classfile.AnnotationEntry;
import org.apache.bcel.classfile.Attribute;
import org.apache.bcel.classfile.ConstantUtf8;
import org.apache.bcel.classfile.ElementValuePair;
import org.apache.bcel.classfile.RuntimeInvisibleAnnotations;
import org.apache.bcel.classfile.RuntimeInvisibleParameterAnnotations;
import org.apache.bcel.classfile.RuntimeVisibleAnnotations;
import org.apache.bcel.classfile.RuntimeVisibleParameterAnnotations;

/* loaded from: org_apache_bcel_generic.jar:org/apache/bcel/generic/AnnotationEntryGen.class */
public class AnnotationEntryGen {
    static final AnnotationEntryGen[] EMPTY_ARRAY = new AnnotationEntryGen[0];
    private int typeIndex;
    private List<ElementValuePairGen> evs;
    private final ConstantPoolGen cpool;
    private boolean isRuntimeVisible;

    /* JADX INFO: Access modifiers changed from: package-private */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v84, types: [java.lang.Throwable, org.apache.bcel.generic.AnnotationEntryGen] */
    public static Attribute[] getAnnotationAttributes(ConstantPoolGen cp, AnnotationEntryGen[] annotationEntryGenArr) {
        if (annotationEntryGenArr.length == 0) {
            return Attribute.EMPTY_ARRAY;
        }
        try {
            int countVisible = 0;
            int countInvisible = 0;
            int length = annotationEntryGenArr.length;
            int i = 0;
            while (i < length) {
                if (annotationEntryGenArr[i].isRuntimeVisible()) {
                    countVisible++;
                } else {
                    countInvisible++;
                }
                i++;
            }
            try {
                ByteArrayOutputStream rvaBytes = new ByteArrayOutputStream();
                ByteArrayOutputStream riaBytes = new ByteArrayOutputStream();
                DataOutputStream rvaDos = new DataOutputStream(rvaBytes);
                Throwable th = null;
                DataOutputStream riaDos = new DataOutputStream(riaBytes);
                Throwable th2 = null;
                try {
                    try {
                        rvaDos.writeShort(countVisible);
                        riaDos.writeShort(countInvisible);
                        for (AnnotationEntryGen annotationEntryGen : annotationEntryGenArr) {
                            if (annotationEntryGen.isRuntimeVisible()) {
                                annotationEntryGen.dump(rvaDos);
                            } else {
                                annotationEntryGen.dump(riaDos);
                            }
                        }
                        if (riaDos != null) {
                            if (0 != 0) {
                                try {
                                    riaDos.close();
                                } catch (Throwable th3) {
                                    th2.addSuppressed(th3);
                                }
                            } else {
                                riaDos.close();
                            }
                        }
                        if (rvaDos != null) {
                            if (0 != 0) {
                                try {
                                    rvaDos.close();
                                } catch (Throwable th4) {
                                    th.addSuppressed(th4);
                                }
                            } else {
                                rvaDos.close();
                            }
                        }
                        byte[] rvaData = rvaBytes.toByteArray();
                        byte[] riaData = riaBytes.toByteArray();
                        int rvaIndex = -1;
                        int riaIndex = -1;
                        if (rvaData.length > 2) {
                            rvaIndex = cp.addUtf8("RuntimeVisibleAnnotations");
                        }
                        if (riaData.length > 2) {
                            riaIndex = cp.addUtf8("RuntimeInvisibleAnnotations");
                        }
                        ArrayList newAttributes = new ArrayList();
                        if (rvaData.length > 2) {
                            newAttributes.add(new RuntimeVisibleAnnotations(rvaIndex, rvaData.length, new DataInputStream(new ByteArrayInputStream(rvaData)), cp.getConstantPool()));
                        }
                        if (riaData.length > 2) {
                            newAttributes.add(new RuntimeInvisibleAnnotations(riaIndex, riaData.length, new DataInputStream(new ByteArrayInputStream(riaData)), cp.getConstantPool()));
                        }
                        return (Attribute[]) newAttributes.toArray(Attribute.EMPTY_ARRAY);
                    } finally {
                    }
                } catch (Throwable th5) {
                    if (riaDos != null) {
                        if (th2 != null) {
                            try {
                                riaDos.close();
                            } catch (Throwable th6) {
                                th2.addSuppressed(th6);
                            }
                        } else {
                            riaDos.close();
                        }
                    }
                    throw th5;
                }
            } finally {
            }
        } catch (IOException e) {
            System.err.println("IOException whilst processing annotations");
            e.printStackTrace();
            return null;
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static Attribute[] getParameterAnnotationAttributes(ConstantPoolGen cp, List<AnnotationEntryGen>[] vec) {
        int[] visCount = new int[vec.length];
        int totalVisCount = 0;
        int[] invisCount = new int[vec.length];
        int totalInvisCount = 0;
        for (int i = 0; i < vec.length; i++) {
            try {
                if (vec[i] != null) {
                    Iterator<AnnotationEntryGen> it = vec[i].iterator();
                    while (it.hasNext()) {
                        if (it.next().isRuntimeVisible()) {
                            int i2 = i;
                            visCount[i2] = visCount[i2] + 1;
                            totalVisCount++;
                        } else {
                            int i3 = i;
                            invisCount[i3] = invisCount[i3] + 1;
                            totalInvisCount++;
                        }
                    }
                }
            } catch (IOException e) {
                System.err.println("IOException whilst processing parameter annotations");
                e.printStackTrace();
                return null;
            }
        }
        ByteArrayOutputStream rvaBytes = new ByteArrayOutputStream();
        DataOutputStream riaDos = new DataOutputStream(rvaBytes);
        Throwable th = null;
        try {
            try {
                riaDos.writeByte(vec.length);
                for (int i4 = 0; i4 < vec.length; i4++) {
                    riaDos.writeShort(visCount[i4]);
                    if (visCount[i4] > 0) {
                        for (AnnotationEntryGen element : vec[i4]) {
                            if (element.isRuntimeVisible()) {
                                element.dump(riaDos);
                            }
                        }
                    }
                }
                if (riaDos != null) {
                    if (0 != 0) {
                        try {
                            riaDos.close();
                        } catch (Throwable th2) {
                            th.addSuppressed(th2);
                        }
                    } else {
                        riaDos.close();
                    }
                }
                ByteArrayOutputStream riaBytes = new ByteArrayOutputStream();
                riaDos = new DataOutputStream(riaBytes);
                Throwable th3 = null;
                try {
                    try {
                        riaDos.writeByte(vec.length);
                        for (int i5 = 0; i5 < vec.length; i5++) {
                            riaDos.writeShort(invisCount[i5]);
                            if (invisCount[i5] > 0) {
                                for (AnnotationEntryGen element2 : vec[i5]) {
                                    if (!element2.isRuntimeVisible()) {
                                        element2.dump(riaDos);
                                    }
                                }
                            }
                        }
                        if (riaDos != null) {
                            if (0 != 0) {
                                try {
                                    riaDos.close();
                                } catch (Throwable th4) {
                                    th3.addSuppressed(th4);
                                }
                            } else {
                                riaDos.close();
                            }
                        }
                        byte[] rvaData = rvaBytes.toByteArray();
                        byte[] riaData = riaBytes.toByteArray();
                        int rvaIndex = -1;
                        int riaIndex = -1;
                        if (totalVisCount > 0) {
                            rvaIndex = cp.addUtf8("RuntimeVisibleParameterAnnotations");
                        }
                        if (totalInvisCount > 0) {
                            riaIndex = cp.addUtf8("RuntimeInvisibleParameterAnnotations");
                        }
                        List<Attribute> newAttributes = new ArrayList<>();
                        if (totalVisCount > 0) {
                            newAttributes.add(new RuntimeVisibleParameterAnnotations(rvaIndex, rvaData.length, new DataInputStream(new ByteArrayInputStream(rvaData)), cp.getConstantPool()));
                        }
                        if (totalInvisCount > 0) {
                            newAttributes.add(new RuntimeInvisibleParameterAnnotations(riaIndex, riaData.length, new DataInputStream(new ByteArrayInputStream(riaData)), cp.getConstantPool()));
                        }
                        return (Attribute[]) newAttributes.toArray(Attribute.EMPTY_ARRAY);
                    } finally {
                    }
                } finally {
                }
            } finally {
            }
        } finally {
        }
    }

    public static AnnotationEntryGen read(DataInput dis, ConstantPoolGen cpool, boolean b) throws IOException {
        AnnotationEntryGen a = new AnnotationEntryGen(cpool);
        a.typeIndex = dis.readUnsignedShort();
        int elemValuePairCount = dis.readUnsignedShort();
        for (int i = 0; i < elemValuePairCount; i++) {
            int nidx = dis.readUnsignedShort();
            a.addElementNameValuePair(new ElementValuePairGen(nidx, ElementValueGen.readElementValue(dis, cpool), cpool));
        }
        a.isRuntimeVisible(b);
        return a;
    }

    public AnnotationEntryGen(AnnotationEntry a, ConstantPoolGen cpool, boolean copyPoolEntries) {
        this.cpool = cpool;
        if (copyPoolEntries) {
            this.typeIndex = cpool.addUtf8(a.getAnnotationType());
        } else {
            this.typeIndex = a.getAnnotationTypeIndex();
        }
        this.isRuntimeVisible = a.isRuntimeVisible();
        this.evs = copyValues(a.getElementValuePairs(), cpool, copyPoolEntries);
    }

    private AnnotationEntryGen(ConstantPoolGen cpool) {
        this.cpool = cpool;
    }

    public AnnotationEntryGen(ObjectType type, List<ElementValuePairGen> elements, boolean vis, ConstantPoolGen cpool) {
        this.cpool = cpool;
        this.typeIndex = cpool.addUtf8(type.getSignature());
        this.evs = elements;
        this.isRuntimeVisible = vis;
    }

    public void addElementNameValuePair(ElementValuePairGen evp) {
        if (this.evs == null) {
            this.evs = new ArrayList();
        }
        this.evs.add(evp);
    }

    private List<ElementValuePairGen> copyValues(ElementValuePair[] in, ConstantPoolGen cpool, boolean copyPoolEntries) {
        List<ElementValuePairGen> out = new ArrayList<>();
        for (ElementValuePair nvp : in) {
            out.add(new ElementValuePairGen(nvp, cpool, copyPoolEntries));
        }
        return out;
    }

    public void dump(DataOutputStream dos) throws IOException {
        dos.writeShort(this.typeIndex);
        dos.writeShort(this.evs.size());
        for (ElementValuePairGen envp : this.evs) {
            envp.dump(dos);
        }
    }

    public AnnotationEntry getAnnotation() {
        AnnotationEntry a = new AnnotationEntry(this.typeIndex, this.cpool.getConstantPool(), this.isRuntimeVisible);
        for (ElementValuePairGen element : this.evs) {
            a.addElementNameValuePair(element.getElementNameValuePair());
        }
        return a;
    }

    public int getTypeIndex() {
        return this.typeIndex;
    }

    public final String getTypeName() {
        return getTypeSignature();
    }

    public final String getTypeSignature() {
        ConstantUtf8 utf8 = this.cpool.getConstant(this.typeIndex);
        return utf8.getBytes();
    }

    public List<ElementValuePairGen> getValues() {
        return this.evs;
    }

    public boolean isRuntimeVisible() {
        return this.isRuntimeVisible;
    }

    private void isRuntimeVisible(boolean b) {
        this.isRuntimeVisible = b;
    }

    public String toShortString() {
        StringBuilder s = new StringBuilder();
        s.append("@").append(getTypeName()).append("(");
        for (int i = 0; i < this.evs.size(); i++) {
            s.append(this.evs.get(i));
            if (i + 1 < this.evs.size()) {
                s.append(",");
            }
        }
        s.append(")");
        return s.toString();
    }

    public String toString() {
        StringBuilder s = new StringBuilder(32);
        s.append("AnnotationGen:[").append(getTypeName()).append(" #").append(this.evs.size()).append(" {");
        for (int i = 0; i < this.evs.size(); i++) {
            s.append(this.evs.get(i));
            if (i + 1 < this.evs.size()) {
                s.append(",");
            }
        }
        s.append("}]");
        return s.toString();
    }
}
